# print-links

This program prints links contained in a given URL to standard output.

## Installation

``` shell
pipx install print-links --include-deps
```

## Usage

``` shell
print-links "URL"
```

> Note: make sure to quote the URL string so that the shell parses it correctly.
